@@ -19,6 +19,8 @@ import re
 
 import u1testutils.mail
 
+TOKEN_REGEX = re.compile(r'/([A-Za-z0-9]{6})/', re.S)
+
 
 def _get_verification_data_for_address(email_address):
     """A private helper for public helpers below.
@@ -35,20 +37,24 @@ def _get_verification_data_for_address(email_address):
         # line longer than a certain length.  Decode now to not have
         # to worry about it in the regexen.
         body = quopri.decodestring(email_msg.get_payload())
-        match = re.search(
-            'Here is your confirmation code:(.*)(Enter|If you made)',
-            body, re.S)
-        if match:
-            vcode = match.group(1).strip()
-        else:
-            raise AssertionError("No verification code found in email.")
+
         links = map(str.strip, re.findall('^(http.*)$', body, re.MULTILINE))
         if len(links) > 0:
             validation_link = links[0]
             if len(links) > 1:
                 invalidation_link = links[1]
+            match = TOKEN_REGEX.search(links[0])
+            if match:
+                vcode = match.group(1).strip()
         else:
-            msg = "No verification link found in email. Email is:\n%r."
+            match = re.search(
+                'Here is your confirmation code:(.*)(Enter|If you made)',
+                body, re.S)
+            if match:
+                vcode = match.group(1).strip()
+
+        if not vcode:
+            msg = "No verification code found in email. Email is:\n%r."
             raise AssertionError(msg % body)
 
     return vcode, validation_link, invalidation_link
